@@ -2,6 +2,7 @@
 # encoding: utf-8
 import re
 import sys
+from html import unescape
 
 import lxml
 from lxml import etree, html
@@ -170,11 +171,6 @@ def get_visible_text(html_content):
     return " ".join(text)
 
 
-def html_unescape(s):
-    h = HTMLParser()
-    return h.unescape(s)
-
-
 def set_response_encoding(request):
     """Set the encoding if it isn't set already.
 
@@ -276,7 +272,7 @@ def fix_links_in_lxml_tree(link, keep_anchors=False):
     url_parts = urlsplit(link)
     url = urlunsplit(
         url_parts[:2]
-        + (re.sub("^(/\.\.)+", "", url_parts.path),)
+        + (re.sub(r"^(/\.\.)+", "", url_parts.path),)
         + url_parts[3:]
     )
     if keep_anchors:
