@@ -9,8 +9,8 @@ class Site(cal.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.court_code = 'A'
-        self.division = '1st App. Dist.'
+        self.court_code = "A"
+        self.division = "1st App. Dist."
         self.url = self.build_url()
 
     def _get_divisions(self):
