@@ -15,5 +15,5 @@ class Site(mass.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.court_identifier = 'AC'
+        self.court_identifier = "AC"
         self.set_local_variables()
