@@ -13,4 +13,4 @@ class Site(tex.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.court_name = 'ccrimapp'
+        self.court_name = "ccrimapp"
