@@ -9,8 +9,7 @@ from juriscraper.opinions.united_states_backscrapers.state import ny
 
 
 class Site(ny.Site):
-
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
-        self.court = 'App+Div,+3d+Dept'
+        self.court = "App+Div,+3d+Dept"
         self.interval = 30
