@@ -67,8 +67,8 @@ class BaseDocketReport(object):
             return {}
 
         data = self.metadata.copy()
-        data[u"parties"] = self.parties
-        data[u"docket_entries"] = self.docket_entries
+        data["parties"] = self.parties
+        data["docket_entries"] = self.docket_entries
         return data
 
     @staticmethod
@@ -80,23 +80,23 @@ class BaseDocketReport(object):
         """
         atty_cache = {}
         for party in parties:
-            for atty in party.get(u"attorneys", []):
-                if not atty[u"contact"]:
+            for atty in party.get("attorneys", []):
+                if not atty["contact"]:
                     continue
 
-                if re.search(r"see\s+above", atty[u"contact"], re.I):
+                if re.search(r"see\s+above", atty["contact"], re.I):
                     try:
-                        atty_info = atty_cache[atty[u"name"]]
+                        atty_info = atty_cache[atty["name"]]
                     except KeyError:
                         # Unable to find the atty in the cache, therefore, we
                         # don't know their contact info.
-                        atty[u"contact"] = u""
+                        atty["contact"] = ""
                     else:
                         # Found the atty in the cache. Use the info.
-                        atty[u"contact"] = atty_info
+                        atty["contact"] = atty_info
                 else:
                     # We have atty info. Save it.
-                    atty_cache[atty[u"name"]] = atty[u"contact"]
+                    atty_cache[atty["name"]] = atty["contact"]
         return parties
 
     def _get_value(self, regex, query_strings, cast_to_date=False):
@@ -200,7 +200,7 @@ class BaseDocketReport(object):
         :param element: Any HTML element
         :return: A list of text nodes from that element split on BRs.
         """
-        sep = u"FLP_SEPARATOR"
+        sep = "FLP_SEPARATOR"
         html_text = tostring(element, encoding="unicode")
         html_text = re.sub(r"<br/?>", sep, html_text, flags=re.I)
         html_text = re.sub(r"<p/?>", sep, html_text, flags=re.I)
@@ -253,14 +253,14 @@ class BaseDocketReport(object):
         label = node.text_content().strip()
         if require_colon and not label.endswith(":"):
             return {}
-        if isinstance(label, str):
-            label = label.decode("utf-8")
+        # if isinstance(label, str):
+        #     label = label.decode("utf-8")
 
         label = (
             label.strip()
             .lower()
             .replace(" ", "_")
-            .replace(u"\xa0", "_")  # Non-breaking space
+            .replace("\xa0", "_")  # Non-breaking space
             .replace("(", "")
             .replace(")", "")
             .rstrip(":")
@@ -385,41 +385,39 @@ class DocketReport(BaseDocketReport, BaseReport):
 
         self._set_metadata_values()
         data = {
-            u"court_id": self.court_id,
-            u"docket_number": self._get_docket_number(),
-            u"case_name": self._get_case_name(),
-            u"date_filed": self._get_value(
+            "court_id": self.court_id,
+            "docket_number": self._get_docket_number(),
+            "case_name": self._get_case_name(),
+            "date_filed": self._get_value(
                 self.date_filed_regex, self.metadata_values, cast_to_date=True
             ),
-            u"date_terminated": self._get_value(
+            "date_terminated": self._get_value(
                 self.date_terminated_regex,
                 self.metadata_values,
                 cast_to_date=True,
             ),
-            u"date_converted": self._get_value(
+            "date_converted": self._get_value(
                 self.date_converted_regex,
                 self.metadata_values,
                 cast_to_date=True,
             ),
-            u"date_discharged": self._get_value(
+            "date_discharged": self._get_value(
                 self.date_discharged_regex,
                 self.metadata_values,
                 cast_to_date=True,
             ),
-            u"assigned_to_str": self._get_judge(self.assigned_to_regex),
-            u"referred_to_str": self._get_judge(self.referred_to_regex),
-            u"cause": self._get_value(self.cause_regex, self.metadata_values),
-            u"nature_of_suit": self._get_nature_of_suit(),
-            u"jury_demand": self._get_value(
+            "assigned_to_str": self._get_judge(self.assigned_to_regex),
+            "referred_to_str": self._get_judge(self.referred_to_regex),
+            "cause": self._get_value(self.cause_regex, self.metadata_values),
+            "nature_of_suit": self._get_nature_of_suit(),
+            "jury_demand": self._get_value(
                 self.jury_demand_regex, self.metadata_values
             ),
-            u"demand": self._get_value(
-                self.demand_regex, self.metadata_values
-            ),
-            u"jurisdiction": self._get_value(
+            "demand": self._get_value(self.demand_regex, self.metadata_values),
+            "jurisdiction": self._get_value(
                 self.jurisdiction_regex, self.metadata_values
             ),
-            u"mdl_status": self._get_value(
+            "mdl_status": self._get_value(
                 self.mdl_status_regex, self.metadata_values
             ),
         }
@@ -492,8 +490,8 @@ class DocketReport(BaseDocketReport, BaseReport):
                 continue
 
             name_path = (
-                u".//b[not(./parent::i)][not(./u)]"
-                u'[not(contains(., "------"))]'
+                ".//b[not(./parent::i)][not(./u)]"
+                '[not(contains(., "------"))]'
             )
             is_party_name_cell = len(cells[0].xpath(name_path)) > 0
             prev_has_disposition = (
@@ -501,24 +499,24 @@ class DocketReport(BaseDocketReport, BaseReport):
             )
             if is_party_name_cell and not prev_has_disposition:
                 element = cells[0].xpath(name_path)[0]
-                party[u"name"] = force_unicode(element.text_content().strip())
-                party[u"extra_info"] = u"\n".join(
+                party["name"] = force_unicode(element.text_content().strip())
+                party["extra_info"] = "\n".join(
                     force_unicode(s.strip())
-                    for s in cells[0].xpath(u".//text()[not(./parent::b)]")
+                    for s in cells[0].xpath(".//text()[not(./parent::b)]")
                     if s.strip()
                 )
-                party[u"date_terminated"] = self._get_value(
+                party["date_terminated"] = self._get_value(
                     self.date_terminated_regex,
-                    party[u"extra_info"],
+                    party["extra_info"],
                     cast_to_date=True,
                 )
 
             if len(cells) == 3 and party != {}:
-                party[u"attorneys"] = self._get_attorneys(cells[2])
+                party["attorneys"] = self._get_attorneys(cells[2])
 
-            if party != {} and party.get(u"type") is None:
+            if party != {} and party.get("type") is None:
                 # Ensure that every record has a type value of some kind.
-                party[u"type"] = u"Unknown"
+                party["type"] = "Unknown"
 
             if party not in parties and party != {}:
                 # Sometimes there are dups in the docket. Avoid them.
@@ -528,7 +526,7 @@ class DocketReport(BaseDocketReport, BaseReport):
                 # In adversary proceedings, there are multiple rows under one
                 # party type header. Nuke the bulk of the party dict, except
                 # for the type so that it's ready for the next iteration.
-                party = {u"type": party[u"type"]}
+                party = {"type": party["type"]}
             else:
                 party = {}
 
@@ -594,25 +592,25 @@ class DocketReport(BaseDocketReport, BaseReport):
         if len(cells) == 1 and cells[0].xpath(".//b/u"):
             # Regular docket - party type value.
             s = force_unicode(cells[0].text_content())
-            return {u"type": normalize_party_types(s)}, True
+            return {"type": normalize_party_types(s)}, True
         elif "------" in row_text:
             # Adversary proceeding
             s = force_unicode(cells[0].text_content().strip())
             if len(cells) == 1:
-                s = re.sub(u"----*", "", s)
-                return {u"type": normalize_party_types(s)}, True
+                s = re.sub("----*", "", s)
+                return {"type": normalize_party_types(s)}, True
             elif len(cells) == 3:
                 # Some courts have malformed HTML that requires extra work.
-                return {u"type": re.split(u"----*", s)[0]}, False
+                return {"type": re.split("----*", s)[0]}, False
         elif all(
             [self.is_bankruptcy, len(cells) == 3, cells[0].xpath(".//i/b")]
         ):
             # Bankruptcy - party type value.
-            s = force_unicode(cells[0].xpath(u".//i")[0].text_content())
-            return {u"type": normalize_party_types(s)}, False
-        elif len(cells) == 3 and u"service list" in row_text:
+            s = force_unicode(cells[0].xpath(".//i")[0].text_content())
+            return {"type": normalize_party_types(s)}, False
+        elif len(cells) == 3 and "service list" in row_text:
             # Special case to handle the service list.
-            return {u"type": u"Service List"}, False
+            return {"type": "Service List"}, False
         else:
             return party, False
 
@@ -647,10 +645,10 @@ class DocketReport(BaseDocketReport, BaseReport):
         # keeping track of which party we're currently working on. Then, when
         # we get useful criminal data, we add it to that party.
         empty_criminal_data = {
-            u"counts": [],
-            u"complaints": [],
-            u"highest_offense_level_opening": "",
-            u"highest_offense_level_terminated": "",
+            "counts": [],
+            "complaints": [],
+            "highest_offense_level_opening": "",
+            "highest_offense_level_terminated": "",
         }
         section_info = {
             "current_section": None,
@@ -694,7 +692,7 @@ class DocketReport(BaseDocketReport, BaseReport):
                 # associate the criminal data.
                 if criminal_data != empty_criminal_data:
                     criminal_data = clean_court_object(criminal_data)
-                    parties[current_party_i][u"criminal_data"] = criminal_data
+                    parties[current_party_i]["criminal_data"] = criminal_data
                 current_party_i += 1
                 # Reset section info and criminal data.
                 criminal_data = copy.deepcopy(empty_criminal_data)
@@ -718,14 +716,14 @@ class DocketReport(BaseDocketReport, BaseReport):
                     # missing.
                     disposition = ""
                 count_name = cells[0].text_content().strip()
-                if count_name == u"None":
+                if count_name == "None":
                     # No counts here. (Happens with terminated ones a lot.)
                     continue
-                criminal_data[u"counts"].append(
+                criminal_data["counts"].append(
                     {
-                        u"name": count_name,
-                        u"disposition": disposition,
-                        u"status": section_info["header_info"],
+                        "name": count_name,
+                        "disposition": disposition,
+                        "status": section_info["header_info"],
                     }
                 )
                 continue
@@ -737,20 +735,20 @@ class DocketReport(BaseDocketReport, BaseReport):
                     # No disposition info.
                     disposition = ""
                 complaint_name = cells[0].text_content()
-                if complaint_name == u"None":
+                if complaint_name == "None":
                     # No counts here. (Happens with terminated ones a lot.)
                     continue
-                criminal_data[u"complaints"].append(
+                criminal_data["complaints"].append(
                     {
-                        u"name": complaint_name,
-                        u"disposition": disposition,
+                        "name": complaint_name,
+                        "disposition": disposition,
                     }
                 )
 
     @staticmethod
     def _values_to_none(d):
         """Set the values for a dictionary all to None"""
-        for k in d.keys():
+        for k in d:
             d[k] = None
 
     def _get_current_section(self, current_section, cells):
@@ -773,8 +771,8 @@ class DocketReport(BaseDocketReport, BaseReport):
         offense_m = self.offense_regex.search(cell_0_text)
         if offense_m:
             return {
-                "current_section": u"highest_offense",
-                "header_info": u"highest_offense_level_%s"
+                "current_section": "highest_offense",
+                "header_info": "highest_offense_level_%s"
                 % offense_m.group("status").lower(),
                 "changed": True,
             }
@@ -782,7 +780,7 @@ class DocketReport(BaseDocketReport, BaseReport):
         counts_m = self.counts_regex.search(cell_0_text)
         if counts_m:
             return {
-                "current_section": u"counts",
+                "current_section": "counts",
                 "header_info": counts_m.group("status").lower(),
                 "changed": True,
             }
@@ -790,7 +788,7 @@ class DocketReport(BaseDocketReport, BaseReport):
         complaint_m = self.complaints_regex.search(cell_0_text)
         if complaint_m:
             return {
-                "current_section": u"complaints",
+                "current_section": "complaints",
                 "header_info": None,
                 "changed": True,
             }
@@ -860,32 +858,32 @@ class DocketReport(BaseDocketReport, BaseReport):
                 atty_node.text_content().strip()
             ).split()
             attorney = {
-                u"name": u" ".join(name_parts),
-                u"roles": [],
-                u"contact": u"",
+                "name": " ".join(name_parts),
+                "roles": [],
+                "contact": "",
             }
-            path = u"./following-sibling::* | ./following-sibling::text()"
+            path = "./following-sibling::* | ./following-sibling::text()"
             for prev, node, nxt in previous_and_next(atty_node.xpath(path)):
                 # noinspection PyProtectedMember
                 if isinstance(
                     node,
                     (etree._ElementStringResult, etree._ElementUnicodeResult),
                 ):
-                    clean_atty = u"%s\n" % " ".join(
+                    clean_atty = "%s\n" % " ".join(
                         n.strip() for n in node.split()
                     )
                     if clean_atty.strip():
-                        attorney[u"contact"] += clean_atty
+                        attorney["contact"] += clean_atty
                 else:
-                    if node.tag == u"i":
+                    if node.tag == "i":
                         role = force_unicode(node.text_content().strip())
                         if not any(
                             [
-                                role.lower().startswith(u"bar status"),
-                                role.lower().startswith(u"designation"),
+                                role.lower().startswith("bar status"),
+                                role.lower().startswith("designation"),
                             ]
                         ):
-                            attorney[u"roles"].append(role)
+                            attorney["roles"].append(role)
 
                 nxt_is_b_tag = isinstance(nxt, HtmlElement) and nxt.tag == "b"
                 if nxt is None or nxt_is_b_tag:
@@ -928,7 +926,7 @@ class DocketReport(BaseDocketReport, BaseReport):
         docket_entries = []
         for row in docket_entry_rows:
             de = {}
-            cells = row.xpath(u"./td[not(./input)]")
+            cells = row.xpath("./td[not(./input)]")
             if len(cells) == 4:
                 # In some instances, the document entry table has an extra
                 # column. See almb, 92-04963
@@ -938,15 +936,15 @@ class DocketReport(BaseDocketReport, BaseReport):
             if not date_filed_str:
                 # Some older dockets have missing dates. Press on.
                 continue
-            de[u"date_filed"] = convert_date_string(date_filed_str)
-            de[u"document_number"] = self._get_document_number(cells[1])
+            de["date_filed"] = convert_date_string(date_filed_str)
+            de["document_number"] = self._get_document_number(cells[1])
             results = self._get_pacer_doc_id_and_seq_no(
-                cells[1], de[u"document_number"]
+                cells[1], de["document_number"]
             )
-            de[u"pacer_doc_id"], de[u"pacer_seq_no"] = results[0], results[1]
-            de[u"description"] = self._get_description(cells)
+            de["pacer_doc_id"], de["pacer_seq_no"] = results[0], results[1]
+            de["description"] = self._get_description(cells)
 
-            number = de[u"document_number"]
+            number = de["document_number"]
             if number is not None and not number.isdigit():
                 # Some courts use the word "doc" instead of a docket number. We
                 # skip these for now.
@@ -963,7 +961,7 @@ class DocketReport(BaseDocketReport, BaseReport):
             return self._is_adversary_proceeding
 
         adversary_proceeding = False
-        path = u'//*[text()[contains(., "Adversary Proceeding")]]'
+        path = '//*[text()[contains(., "Adversary Proceeding")]]'
         if self.tree.xpath(path):
             adversary_proceeding = True
 
@@ -1019,67 +1017,67 @@ class DocketReport(BaseDocketReport, BaseReport):
             "pacer_case_id must be truthy, not '%s'" % pacer_case_id
         )
 
-        if date_range_type not in [u"Filed", u"Entered"]:
-            raise ValueError(u"Invalid value for 'date_range_type' parameter.")
-        if output_format not in [u"html", u"pdf"]:
-            raise ValueError(u"Invalid value for 'output_format' parameter.")
-        if order_by == u"date":
-            order_by = u"oldest date first"
-        elif order_by == u"-date":
-            order_by = u"most recent date first"
-        elif order_by == u"document_number":
-            order_by = u"document number"
+        if date_range_type not in ["Filed", "Entered"]:
+            raise ValueError("Invalid value for 'date_range_type' parameter.")
+        if output_format not in ["html", "pdf"]:
+            raise ValueError("Invalid value for 'output_format' parameter.")
+        if order_by == "date":
+            order_by = "oldest date first"
+        elif order_by == "-date":
+            order_by = "most recent date first"
+        elif order_by == "document_number":
+            order_by = "document number"
         else:
-            raise ValueError(u"Invalid value for 'order_by' parameter.")
+            raise ValueError("Invalid value for 'order_by' parameter.")
 
         if show_terminated_parties and not show_parties_and_counsel:
             raise ValueError(
-                u"Cannot show terminated parties if parties and "
-                u"counsel are not also requested."
+                "Cannot show terminated parties if parties and "
+                "counsel are not also requested."
             )
 
         query_params = {
-            u"all_case_ids": pacer_case_id,
-            u"sort1": order_by,
-            u"date_range_type": date_range_type,
-            u"output_format": output_format,
+            "all_case_ids": pacer_case_id,
+            "sort1": order_by,
+            "date_range_type": date_range_type,
+            "output_format": output_format,
             # Any value works in this parameter, but it cannot be blank.
             # Normally this would have a value like '3:12-cv-3879', but that's
             # not even necessary.
-            u"case_num": u" "
+            "case_num": " "
             # These fields seem to be unnecessary/unused.
             # 'view_comb_doc_text': '',
             # 'PreResetField': '',
             # 'PreResetFields': '',
         }
         if date_start:
-            query_params[u"date_from"] = date_start.strftime(u"%m/%d/%Y")
+            query_params["date_from"] = date_start.strftime("%m/%d/%Y")
         else:
             # If it's a big docket and you don't filter it in some form you get
             # an intermediate page that says, paraphrasing: "Do you really want
             # to pull that whole, big, docket?" However, if we always make sure
             # to have this field populated, we don't see that page. ∴, always
             # set this value. See #210.
-            query_params[u"date_from"] = "1/1/1960"
+            query_params["date_from"] = "1/1/1960"
         if date_end:
-            query_params[u"date_to"] = date_end.strftime(u"%m/%d/%Y")
+            query_params["date_to"] = date_end.strftime("%m/%d/%Y")
         if doc_num_start:
-            query_params[u"documents_numbered_from_"] = str(int(doc_num_start))
+            query_params["documents_numbered_from_"] = str(int(doc_num_start))
         if doc_num_end:
-            query_params[u"documents_numbered_to_"] = str(int(doc_num_end))
+            query_params["documents_numbered_to_"] = str(int(doc_num_end))
         if show_parties_and_counsel is True:
-            query_params[u"list_of_parties_and_counsel"] = u"on"
+            query_params["list_of_parties_and_counsel"] = "on"
         if show_terminated_parties is True:
-            query_params[u"terminated_parties"] = u"on"
+            query_params["terminated_parties"] = "on"
         if show_list_of_member_cases is True:
-            query_params[u"list_of_member_cases"] = u"on"
+            query_params["list_of_member_cases"] = "on"
         if include_pdf_headers is True:
-            query_params[u"pdf_header"] = u"1"
+            query_params["pdf_header"] = "1"
         if show_multiple_docs is True:
-            query_params[u"view_multi_docs"] = u"on"
+            query_params["view_multi_docs"] = "on"
 
         logger.info(
-            u"Querying docket report for case ID '%s' with params %s"
+            "Querying docket report for case ID '%s' with params %s"
             % (pacer_case_id, query_params)
         )
 
@@ -1092,11 +1090,11 @@ class DocketReport(BaseDocketReport, BaseReport):
         # The first ancestor table of the table cell containing "date filed"
         table = self.tree.xpath(
             # Match any td containing Date [fF]iled
-            u'//td[.//text()[contains(translate(., "f", "F"), "Date Filed:")]]'
+            '//td[.//text()[contains(translate(., "f", "F"), "Date Filed:")]]'
             # And find its highest ancestor table that lacks a center tag.
-            u"/ancestor::table[not(.//center)][last()]"
+            "/ancestor::table[not(.//center)][last()]"
         )[0]
-        cells = table.xpath(u".//td")
+        cells = table.xpath(".//td")
         # Convert the <br> separated content into text strings, treating as
         # much as possible as HTML.
         values = []
@@ -1114,7 +1112,7 @@ class DocketReport(BaseDocketReport, BaseReport):
             # We find the first link having the document number as text.
             # This is needed because txnb combines the second and third
             # column in their docket report.
-            anchors = cell.xpath(u".//a")
+            anchors = cell.xpath(".//a")
             if len(anchors) == 0:
                 # Docket entry exists, but cannot download document (it's
                 # sealed, a minute entry, or otherwise unavailable in PACER).
@@ -1139,8 +1137,8 @@ class DocketReport(BaseDocketReport, BaseReport):
             word for phrase in self._br_split(cell) for word in phrase.split()
         ]
         if words:
-            first_word = re.sub(u"[\s\u00A0]", "", words[0])
-            if self.court_id == u"txnb":
+            first_word = re.sub("[\s\u00A0]", "", words[0])
+            if self.court_id == "txnb":
                 # txnb merges the second and third columns, so if the first
                 # word is a number, return it. Otherwise, assume doc number
                 # isn't listed for the item.
@@ -1151,7 +1149,7 @@ class DocketReport(BaseDocketReport, BaseReport):
         return None
 
     def _get_description(self, cells):
-        if self.court_id != u"txnb":
+        if self.court_id != "txnb":
             return force_unicode(cells[2].text_content())
 
         s = force_unicode(cells[1].text_content())
@@ -1159,17 +1157,17 @@ class DocketReport(BaseDocketReport, BaseReport):
         # combined. The field can have one of four formats. Attempt the most
         # detailed first, then work our way down to just giving up and
         # capturing it all.
-        ws = u"[\s\u00A0]"  # Whitespace including nbsp
+        ws = "[\s\u00A0]"  # Whitespace including nbsp
         regexes = [
             # 2 (23 pgs; 4 docs) Blab blah (happens when attachments exist and
             # page numbers are on)
-            u"^{ws}*\d+{ws}+\(\d+{ws}+pgs;{ws}\d+{ws}docs\){ws}+(.*)",
+            r"^{ws}*\d+{ws}+\(\d+{ws}+pgs;{ws}\d+{ws}docs\){ws}+(.*)",
             # 2 (23 pgs) Blab blah (happens when pg nums are on)
-            u"^{ws}*\d+{ws}+\(\d+{ws}+pgs\){ws}+(.*)",
+            r"^{ws}*\d+{ws}+\(\d+{ws}+pgs\){ws}+(.*)",
             # 2 Blab blah (happens when page nums are off)
-            u"^{ws}*\d+{ws}+(.*)",
+            r"^{ws}*\d+{ws}+(.*)",
             # Blab blah (happens when a doc is sealed; can't be downloaded)
-            u"^{ws}*(.*)",
+            r"^{ws}*(.*)",
         ]
         for regex in regexes:
             try:
@@ -1188,21 +1186,21 @@ class DocketReport(BaseDocketReport, BaseReport):
                 return [
                     p
                     for p in self.parties
-                    if p[u"type"] == u"Debtor"
-                    or p[u"type"] == u"Debtor In Possession"
-                ][0][u"name"]
+                    if p["type"] == "Debtor"
+                    or p["type"] == "Debtor In Possession"
+                ][0]["name"]
             except IndexError:
                 pass
 
             # This is probably a sub docket to a larger case. Use that title.
             try:
-                path = u'//i[contains(., "Lead BK Title")]/following::text()'
+                path = '//i[contains(., "Lead BK Title")]/following::text()'
                 case_name = self.tree.xpath(path)[0].strip()
             except IndexError:
-                case_name = u"Unknown Case Title"
+                case_name = "Unknown Case Title"
 
             if self.is_adversary_proceeding:
-                case_name += u" - Adversary Proceeding"
+                case_name += " - Adversary Proceeding"
         else:
             # Skip the last value, it's a concat of all previous values and
             # isn't needed for case name matching.
@@ -1229,7 +1227,7 @@ class DocketReport(BaseDocketReport, BaseReport):
 
             if case_name is None:
                 # All parsing has failed. Give up.
-                case_name = u"Unknown Case Title"
+                case_name = "Unknown Case Title"
 
         return clean_string(harmonize(case_name))
 
@@ -1245,13 +1243,13 @@ class DocketReport(BaseDocketReport, BaseReport):
     def _get_nature_of_suit(self):
         if self.is_adversary_proceeding:
             # Add the next table too, if it contains the nature of suit.
-            path = u'//table[contains(., "Nature[s] of")]//tr'
+            path = '//table[contains(., "Nature[s] of")]//tr'
             rows = self.tree.xpath(path)
             nos = []
             for row in rows:
                 cell_texts = [
                     force_unicode(s.strip())
-                    for s in row.xpath(u"./td[position() > 2]/text()")
+                    for s in row.xpath("./td[position() > 2]/text()")
                     if s.strip()
                 ]
                 if len(cell_texts) > 1:
